# What does this MR do and why?

# MR acceptance checklist

Please confirm that this pull request has done the following:

- [ ] New notebook based on `notebooks/example.py`
- [ ] Documentation and metadata added
- [ ] Description in ``CHANGELOG.rst`` added
- [ ] Book has been published and verified with the CI

/label ~"New Book"
